summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui/UI.java
diff options
context:
space:
mode:
Diffstat (limited to 'server/src/com/vaadin/ui/UI.java')
-rw-r--r--server/src/com/vaadin/ui/UI.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/server/src/com/vaadin/ui/UI.java b/server/src/com/vaadin/ui/UI.java
index 3cacf5c497..0954bbec13 100644
--- a/server/src/com/vaadin/ui/UI.java
+++ b/server/src/com/vaadin/ui/UI.java
@@ -149,7 +149,7 @@ public abstract class UI extends AbstractComponentContainer implements
* to a window. All windows can be accessed through
* {@code http://host:port/app/win} where {@code http://host:port/app}
* is the application URL (as returned by
* {@link VaadinServiceSession#getURL()} and {@code win} is the window
* name.
* </p>
* <p>
@@ -170,7 +170,7 @@ public abstract class UI extends AbstractComponentContainer implements
* to a window. All windows can be accessed through
* {@code http://host:port/app/win} where {@code http://host:port/app}
* is the application URL (as returned by
* {@link VaadinServiceSession#getURL()} and {@code win} is the window
* name.
* </p>
* <p>
@@ -208,13 +208,13 @@ public abstract class UI extends AbstractComponentContainer implements
* to an application
*/
public URL getURL() {
- VaadinServiceSession session = getSession();
- if (session == null) {
+ LegacyApplication application = getApplication();
+ if (application == null) {
return null;
}
try {
- return new URL(session.getURL(), getName() + "/");
+ return new URL(application.getURL(), getName() + "/");
} catch (MalformedURLException e) {
throw new RuntimeException(
"Internal problem getting window URL, please report");
@@ -149,7 +149,7 @@ public abstract class UI extends AbstractComponentContainer implements
* {@code http://host:port/app/win} where {@code http://host:port/app}
* is the application URL (as returned by
- * {@link VaadinServiceSession#getURL()} and {@code win} is the window
+ * {@link LegacyApplication#getURL()} and {@code win} is the window
* name.
* </p>
@@ -170,7 +170,7 @@ public abstract class UI extends AbstractComponentContainer implements
* {@code http://host:port/app/win} where {@code http://host:port/app}
* is the application URL (as returned by
- * {@link VaadinServiceSession#getURL()} and {@code win} is the window
+ * {@link LegacyApplication#getURL()} and {@code win} is the window
* name.
* </p>